@@ -332,21 +332,24 @@ e_gw_item_to_cal_component (EGwItem *item, icaltimezone *default_zone)
 	/* start date */
 	/* should i duplicate here ? */
 	t = e_gw_item_get_start_date (item);
-	itt_utc = icaltime_from_string (t);
-	if (!icaltime_get_timezone (itt_utc))
-		icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone());
-	if (default_zone) {
-		itt = icaltime_convert_to_zone (itt_utc, default_zone); 
-		icaltime_set_timezone (&itt, default_zone);
-		dt.value = &itt;
-		dt.tzid = icaltimezone_get_tzid (default_zone);
-	} else {
-		dt.value = &itt_utc;
-		dt.tzid = g_strdup ("UTC");
+	if (t) {
+		itt_utc = icaltime_from_string (t);
+		if (!icaltime_get_timezone (itt_utc))
+			icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone());
+		if (default_zone) {
+			itt = icaltime_convert_to_zone (itt_utc, default_zone); 
+			icaltime_set_timezone (&itt, default_zone);
+			dt.value = &itt;
+			dt.tzid = icaltimezone_get_tzid (default_zone);
+		} else {
+			dt.value = &itt_utc;
+			dt.tzid = g_strdup ("UTC");
+		}
+		e_cal_component_set_dtstart (comp, &dt);
+		g_free (t);
 	}
-	e_cal_component_set_dtstart (comp, &dt);
-	g_free (t);
-
+	else 
+		return NULL;
 	
 
 	/* classification */
@@ -380,20 +383,23 @@ e_gw_item_to_cal_component (EGwItem *item, icaltimezone *default_zone)
 
 		/* end date */
 		t = e_gw_item_get_end_date (item);
-		itt_utc = icaltime_from_string (t);
-		if (!icaltime_get_timezone (itt_utc))
-			icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone());
-		if (default_zone) {
-			itt = icaltime_convert_to_zone (itt_utc, default_zone); 
-			icaltime_set_timezone (&itt, default_zone);
-			dt.value = &itt;
-			dt.tzid = icaltimezone_get_tzid (default_zone);
-		} else {
-			dt.value = &itt_utc;
-			dt.tzid = g_strdup ("UTC");
+		if (t) {
+			itt_utc = icaltime_from_string (t);
+			if (!icaltime_get_timezone (itt_utc))
+				icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone());
+			if (default_zone) {
+				itt = icaltime_convert_to_zone (itt_utc, default_zone); 
+				icaltime_set_timezone (&itt, default_zone);
+				dt.value = &itt;
+				dt.tzid = icaltimezone_get_tzid (default_zone);
+			} else {
+				dt.value = &itt_utc;
+				dt.tzid = g_strdup ("UTC");
+			}
+		
+			e_cal_component_set_dtend (comp, &dt);
 		}
 		
-		e_cal_component_set_dtend (comp, &dt);
 
 		/* alarms*/
 		/* we negate the value as GW supports only "before" the start of event alarms */
@@ -438,6 +444,8 @@ e_gw_item_to_cal_component (EGwItem *item, icaltimezone *default_zone)
 	case E_GW_ITEM_TYPE_TASK :
 		/* due date */
 		t = e_gw_item_get_due_date (item);
+		if (!t)
+			break;
 		itt_utc = icaltime_from_string (t);
 		if (!icaltime_get_timezone (itt_utc))
 			icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone());
@@ -525,10 +533,6 @@ start_freebusy_session (EGwConnection *cnc, GList *users,
 
         soup_soap_message_end_element (msg);
 
-        /*FIXME check if this needs to be formatted into GW form with separators*/
-        /*FIXME  the following code converts time_t to String representation
-         * through icaltime. Find if a direct conversion exists.  */ 
-        /* Timezone in server is assumed to be UTC */
 
 	utc = icaltimezone_get_utc_timezone ();
 	icaltime = icaltime_from_timet_with_zone (start, FALSE, utc);
@@ -793,17 +797,7 @@ e_gw_item_set_changes (EGwItem *item, EGwItem *cache_item)
 
 		if (strcmp (e_gw_item_get_end_date (item), e_gw_item_get_end_date (cache_item)))
 			e_gw_item_set_change (item, E_GW_ITEM_CHANGE_TYPE_UPDATE, "endDate", e_gw_item_get_end_date (item));
-		accept_level = e_gw_item_get_accept_level (item);                                                       
-		cache_accept_level = e_gw_item_get_accept_level (cache_item);                                           
-		if ( cache_accept_level ) {                                                                            
-			if (!accept_level )                                                                               
-				e_gw_item_set_change (item, E_GW_ITEM_CHANGE_TYPE_DELETE, "acceptLevel", cache_accept_level );
-			else if (strcmp ( accept_level, cache_accept_level ))                                               
-				e_gw_item_set_change (item, E_GW_ITEM_CHANGE_TYPE_UPDATE, "acceptLevel", accept_level );
-		}                                                                                                 
-		else if ( accept_level )                                                                               
-			e_gw_item_set_change (item, E_GW_ITEM_CHANGE_TYPE_ADD, "acceptLevel", accept_level ); 
-		
+		SET_DELTA(accept_level);
 		SET_DELTA(place);
 		trigger = e_gw_item_get_trigger (item);
 		cache_trigger = e_gw_item_get_trigger (cache_item);
